@@ -13,11 +13,11 @@ Class::CGI - Fetch objects from your CGI object
 
 =head1 VERSION
 
-Version 0.10
+Version 0.11
 
 =cut
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 =head1 SYNOPSIS
 
@@ -323,7 +323,7 @@ sub param {
     my $result;
     eval { $result = $class->new( $self, $param ) };
     if ( my $error = $@ ) {
-        $self->_add_error($error);
+        $self->_add_error($param, $error);
         return;
     }
     return $result;
@@ -369,11 +369,15 @@ C<&param> method.  For example, let's consider the following:
     my $date     = $cgi->param('date');
     my $order    = $cgi->param('order');
 
-    if ( my @errors = $cgi->errors ) {
+    if ( my %errors = $cgi->errors ) {
        # do error handling
     }
 
-If any of the C<< $cgi->param >> calls generats an error, it will B<not> throw
+If errors are generated by the param statements, returns a hash of the errors.
+The keys are the param names and the values are whatever exception the handler
+throws.  Returns a hashref in scalar context.
+
+If any of the C<< $cgi->param >> calls generates an error, it will B<not> throw
 an exception.  Instead, control will pass to the next statement.  After all
 C<< $cgi->param >> calls are made, you can check the C<&errors> method to see
 if any errors were generated and, if so, handle them appropriately.
@@ -390,7 +394,7 @@ and should be avoided at all costs.
 sub errors {
     my $self = shift;
     return wantarray
-      ? @{ $self->{class_cgi_errors} || [] }
+      ? %{ $self->{class_cgi_errors} || {} }
       : $self->{class_cgi_errors};
 }
 
@@ -406,13 +410,14 @@ Deletes all errors returned by the C<&errors> method.
 
 sub clear_errors {
     my $self = shift;
-    $self->{class_cgi_errors} = [];
+    $self->{class_cgi_errors} = {};
     return $self;
 }
 
 sub _add_error {
-    my $self = shift;
-    push @{ $self->{class_cgi_errors} }, shift;
+    my ($self, $param, $error) = @_;
+    $self->{class_cgi_errors}{$param} = $error;
+    return $self;
 }
 
 sub _croak {
